@@ -1,20 +1,35 @@
 import sys
-from .preprocessingMerge import Word, mergeQuotations, mergeNamedEntityTag
-from nltk.stem.wordnet import WordNetLemmatizer
-from nltk.stem.porter import PorterStemmer
+from .preprocessingMerge import Word, mergeQuotations, mergeNamedEntityTag, buildWord
+from copy import deepcopy
 
 class DependenciesTree:
     """
         One node of the parse tree.
         It is a group of words of the initial sentence.
     """
-    def __init__(self, word, namedentitytag='undef', dependency='undef', child=None, parent=None):
-        self.wordList = [Word(word[:word.rindex('-')],int(word[word.rindex('-')+1:]))] # words of the node
-        self.namedEntityTag = namedentitytag 
-        self.dependency = dependency # dependency from self to its parent
-        self.child = child or [] # children of self
-        self.text = "" # each node contains whole sentence
-        self.parent=parent # parent of self
+    def __init__(self, word, namedEntityTag='undef', subtreeType='undef', dependency='undef', child=None, parent=None):
+        self.wordList = [buildWord(word)]     # list of the words contained in the node 
+        self.namedEntityTag = namedEntityTag  # NER tag (location, ...)
+        self.subtreeType = subtreeType        # type of the info represented by the subtree
+        self.dependency = dependency          # dependency from self to its parent
+        self.child = child or []              # children of self
+        self.text = ""                        # each node contains the initial whole sentence
+        self.parent = parent                  # parent of self
+        self.dfsTag = 0                       # number attributed by a dfs
+
+    def dfsAnnotate(self,n):
+        """
+            Build a dfs annotation on the tree
+            Useful to distinguish (in printing) nodes that are different but contain the same wordList
+        """
+        if self.child == []:
+            self.dfsTag = n
+            return n+1
+        else:
+            for t in self.child:
+                n = t.dfsAnnotate(n)
+            self.dfsTag = n+1
+            return n+1
 
     def string(self):
         # Concatenation of the words of the root
@@ -24,10 +39,12 @@ class DependenciesTree:
         t=''
         if(self.namedEntityTag != 'O' and self.namedEntityTag != 'undef'):
             t+= " [{0}]".format(self.namedEntityTag)
-        s+="\t\"{0}\"[label=\"{1}{2}\",shape=box];\n".format(self.wordList[0].word+str(self.wordList[0].index),w,t)
+        if self.subtreeType != 'undef':
+            t+= " [$ {0}]".format(self.subtreeType)
+        s+="\t\"{0}\"[label=\"{1}{2}\",shape=box];\n".format(self.wordList[0].word+str(self.dfsTag),w,t)
         # Adding definitions of the edges
         for n in self.child:
-            s+="\t\"{0}\" -> \"{1}\"[label=\"{2}\"];\n".format(self.wordList[0].word+str(self.wordList[0].index),n.wordList[0].word+str(n.wordList[0].index),n.dependency)
+            s+="\t\"{0}\" -> \"{1}\"[label=\"{2}\"];\n".format(self.wordList[0].word+str(self.dfsTag),n.wordList[0].word+str(n.dfsTag),n.dependency)
         # Recursive calls
         for n in self.child:
             s+=n.string()
@@ -37,6 +54,7 @@ class DependenciesTree:
         """
             Print dependency graph in dot format
         """
+        self.dfsAnnotate(0)
         return "digraph relations {"+"\n{0}\tlabelloc=\"t\"\tlabel=\"{1}\";\n".format(self.string(),self.text)+"}"
 
     def merge(self,other,mergeWords):
@@ -118,13 +136,6 @@ def initText(t,s):
     for c in t.child:
         initText(c,s)
 
-def normalize(t,lmtzr,st):
-    for c in t.child:
-        normalize(c,lmtzr,st)
-    if t.namedEntityTag == 'undef':
-        for w in t.wordList:
-            w.normalize(lmtzr,st)
-
 def computeTree(r):
     """
         Compute the dependence tree.
@@ -132,14 +143,11 @@ def computeTree(r):
         Apply quotation and NER merging
         Return the root of the tree (word 'ROOT-0').
     """
-    nameToNodes = {} # map from the original string to the node
+    nameToNodes = {}                             # map from the original string to the node
     computeEdges(r,nameToNodes)
     computeTags(r,nameToNodes)
-    tree = nameToNodes['ROOT-0']
+    tree = nameToNodes['ROOT-0']                 # the tree is built
     initText(tree,r['text'].replace('"','\\\"'))
-    mergeQuotations(tree,r) # quotation merging
-    mergeNamedEntityTag(tree) # NER merging
-    lmtzr = WordNetLemmatizer()
-    st = PorterStemmer()
-    normalize(tree,lmtzr,st) # normalize words (lemmatization + nounify nouns)
+    mergeQuotations(tree,r)                      # quotation merging
+    mergeNamedEntityTag(tree)                    # NER merging
     return tree
